==> Iuno-3.0.1.10898.tar.gz: Iuno-3.0.1.10898/Iuno/cloud/newsletter/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: Backend.py 10410 2017-10-24 11:52:16Z David $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2017-10-24 19:52:16 +0800 (Tue, 24 Oct 2017) $
# $Revision: 10410 $

from urllib import urlopen, urlencode, quote
from django.core.mail.backends.base import BaseEmailBackend
from django.conf import settings

from Iuppiter.Encoding import utf8, _unicode
from Iuppiter.Json import serializer

class EmailBackend(BaseEmailBackend):

    def __init__(self, host=None, port=None, username=None, password=None,
                 use_tls=None, fail_silently=False, **kwargs):
        """
        Constructor.
        """
        super(EmailBackend, self).__init__(fail_silently=fail_silently)

        if not username:
            username = settings.EMAIL_HOST_USER 
            password = settings.EMAIL_HOST_PASSWORD
            host = settings.EMAIL_HOST
            use_tls = settings.EMAIL_USE_TLS
            port = settings.EMAIL_PORT

        # username input:
        # admin$templates_shop$templates_shop_mails
        if '$' in username:
            appInfo = username.split('$')
            self.username = appInfo[0]
            self.appName = appInfo[1]
            if len(appInfo) > 2:
                self.groupName = appInfo[2]
            else:
                self.groupName = ''
        else:
            self.username = username
            
        self.password = password

        if settings.DEFAULT_FROM_EMAIL:
            self.from_email = settings.DEFAULT_FROM_EMAIL

        if host is None:
            host = 'localhost'

        _port = ':%s' % str(port) if port else ''
        _domain = '%s%s/newsletters/api/' % (host, _port)

        if use_tls is True:
            _scheme = 'https'
        else:
            _scheme = 'http'

        self.domain = '%s://%s' % (_scheme, _domain)

        self.kwargs = kwargs

    def parseResult(self, content):
        """
        Parse content.

        @param content Content.
        """
        try:
            content = serializer.deserialize(content)
            if 'error' in content:
                raise RuntimeError(
                    '[parseResult]:\n'
                    '%s: %s' % (content['error'], content['message']))
            else:
                return content
        except Exception as e:
            raise e

    def _getToken(self, app):
        """
        Get token.

        @param app App name.
        """

        try:
            data = urlencode({
                'user': self.username,
                'pwd': self.password,
                'app': utf8(app)
            })
            link = '%sapp/login/' % self.domain
            result = urlopen(link, data=data).read()
            result = self.parseResult(result)
            return result['token']
        except Exception as e:
            raise e

    def send_messages(self, email_messages):
        """
        Send messages.

        @param email_messages Email messages.
        """
        if not email_messages:
            return

        for email in email_messages:
            app = email.extra_headers.get('app', '')
            if not app:
                app = self.appName
            token = self._getToken(app)
            title = utf8(email.subject)
            
            if '$' in email.from_email and not '@' in email.from_email:
                fromMail = self.from_email
            else:
                fromMail = email.from_email

            if email.content_subtype == 'html':
                emailText = email.body
            else:
                if hasattr(email, 'alternatives') and email.alternatives:
                    # if email is multipart/alternative email
                    # [(u'\n<p xmlns="http:/...eam</p>\n', 'text/html')]
                    # see https://docs.djangoproject.com/en/1.11/topics/
                    #     email/#send-mail
                    emailText = email.alternatives[0][0]
                else:
                    emailText = '<pre>%s</pre>' % (email.body, )

            data = {
                'token': token,
                'title': title,
                'emails': ','.join(email.to),
                'text': utf8(emailText),
                'sender': fromMail,
            }

            replyTo = email.extra_headers.get('Reply-To', '')
            if replyTo:
                data['reply'] = replyTo

            senderEmail = email.extra_headers.get('Sender', '')
            if senderEmail:
                data['sender'] = senderEmail

            group = email.extra_headers.get('group', '')
            if group:
                data['group'] = utf8(group)
            else:
                data['group'] = self.groupName if self.groupName else title

            data = urlencode(data)

            attachData = {}
            for (n, attach) in enumerate(email.attachments):
                nameKey = 'attachmentName%d' % (n + 1)
                contentKey = 'attachmentContent%d' % (n + 1)
                typeKey = 'attachmentType%d' % (n + 1)

                name, content, cType = attach

                if name:
                    attachData.update({
                        nameKey: quote(name),
                    })

                if cType:
                    attachData.update({
                        typeKey: quote(cType),
                    })

                attachData.update({
                    contentKey: quote(content),
                })
            data = '%s&%s' % (data, urlencode(attachData))

            try:
                link = '%sapp/mail/' % self.domain
                result = urlopen(link, data=data).read()
                result = self.parseResult(result)
                return result
            except Exception as e:
                raise e

==> Iuno-3.2.0.10940.tar.gz: Iuno-3.2.0.10940/Iuno/cloud/newsletter/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: Backend.py 10410 2017-10-24 11:52:16Z David $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2017-10-24 19:52:16 +0800 (Tue, 24 Oct 2017) $
# $Revision: 10410 $

from six.moves.urllib.parse import quote, urlencode
from six.moves.urllib.request import urlopen
from django.core.mail.backends.base import BaseEmailBackend
from django.conf import settings

from Iuppiter.Encoding import utf8, _unicode
from Iuppiter.Json import serializer

class EmailBackend(BaseEmailBackend):

    def __init__(self, host=None, port=None, username=None, password=None,
                 use_tls=None, fail_silently=False, **kwargs):
        """
        Constructor.
        """
        super(EmailBackend, self).__init__(fail_silently=fail_silently)

        if not username:
            username = settings.EMAIL_HOST_USER 
            password = settings.EMAIL_HOST_PASSWORD
            host = settings.EMAIL_HOST
            use_tls = settings.EMAIL_USE_TLS
            port = settings.EMAIL_PORT

        # username input:
        # admin$templates_shop$templates_shop_mails
        if '$' in username:
            appInfo = username.split('$')
            self.username = appInfo[0]
            self.appName = appInfo[1]
            if len(appInfo) > 2:
                self.groupName = appInfo[2]
            else:
                self.groupName = ''
        else:
            self.username = username
            
        self.password = password

        if settings.DEFAULT_FROM_EMAIL:
            self.from_email = settings.DEFAULT_FROM_EMAIL

        if host is None:
            host = 'localhost'

        _port = ':%s' % str(port) if port else ''
        _domain = '%s%s/newsletters/api/' % (host, _port)

        if use_tls is True:
            _scheme = 'https'
        else:
            _scheme = 'http'

        self.domain = '%s://%s' % (_scheme, _domain)

        self.kwargs = kwargs

    def parseResult(self, content):
        """
        Parse content.

        @param content Content.
        """
        try:
            content = serializer.deserialize(content)
            if 'error' in content:
                raise RuntimeError(
                    '[parseResult]:\n'
                    '%s: %s' % (content['error'], content['message']))
            else:
                return content
        except Exception as e:
            raise e

    def _getToken(self, app):
        """
        Get token.

        @param app App name.
        """

        try:
            data = urlencode({
                'user': self.username,
                'pwd': self.password,
                'app': utf8(app)
            })
            link = '%sapp/login/' % self.domain
            result = urlopen(link, data=data).read()
            result = self.parseResult(result)
            return result['token']
        except Exception as e:
            raise e

    def send_messages(self, email_messages):
        """
        Send messages.

        @param email_messages Email messages.
        """
        if not email_messages:
            return

        for email in email_messages:
            app = email.extra_headers.get('app', '')
            if not app:
                app = self.appName
            token = self._getToken(app)
            title = utf8(email.subject)
            
            if '$' in email.from_email and not '@' in email.from_email:
                fromMail = self.from_email
            else:
                fromMail = email.from_email

            if email.content_subtype == 'html':
                emailText = email.body
            else:
                if hasattr(email, 'alternatives') and email.alternatives:
                    # if email is multipart/alternative email
                    # [(u'\n<p xmlns="http:/...eam</p>\n', 'text/html')]
                    # see https://docs.djangoproject.com/en/1.11/topics/
                    #     email/#send-mail
                    emailText = email.alternatives[0][0]
                else:
                    emailText = '<pre>%s</pre>' % (email.body, )

            data = {
                'token': token,
                'title': title,
                'emails': ','.join(email.to),
                'text': utf8(emailText),
                'sender': fromMail,
            }

            replyTo = email.extra_headers.get('Reply-To', '')
            if replyTo:
                data['reply'] = replyTo

            senderEmail = email.extra_headers.get('Sender', '')
            if senderEmail:
                data['sender'] = senderEmail

            group = email.extra_headers.get('group', '')
            if group:
                data['group'] = utf8(group)
            else:
                data['group'] = self.groupName if self.groupName else title

            data = urlencode(data)

            attachData = {}
            for (n, attach) in enumerate(email.attachments):
                nameKey = 'attachmentName%d' % (n + 1)
                contentKey = 'attachmentContent%d' % (n + 1)
                typeKey = 'attachmentType%d' % (n + 1)

                name, content, cType = attach

                if name:
                    attachData.update({
                        nameKey: quote(name),
                    })

                if cType:
                    attachData.update({
                        typeKey: quote(cType),
                    })

                attachData.update({
                    contentKey: quote(content),
                })
            data = '%s&%s' % (data, urlencode(attachData))

            try:
                link = '%sapp/mail/' % self.domain
                result = urlopen(link, data=data).read()
                result = self.parseResult(result)
                return result
            except Exception as e:
                raise e
